/*

    File:     store_color.c

    Ref. No:  design.io.graphics.x.3

    Author:   James Garacci

    Date:     DEC-8-1994

    Purpose:

	The purpose of this module is to to store a color in the system
	colormap.

    Usage:

	This module can be invoked as follows:

		pixel = store_color (display
				    ,visual
				    ,colormap
				    ,new_color);

    Input Parameters:

	display = a pointer to the structure containing the information about
		  the display to be used.

	visual = a pointer to the structure containing the information about
		 the visual to be used.

	colormap = a structure of type Colormap where the information about the
		   system colormap to be used is stored.

	new_color = a pointer to a structure of type XColor where the RGB
		    information about the color to be stored is located.

    Output Parameters:

	pixel = a long integer used to hold the value of the pixel as it is 
		stored in the colormap.

    Side Effects:

	None

    Include Files: */

#include <stdio.h>
#include <X11/Xlib.h>

/*  Functions Referenced:

	None

**  System Calls:

	printf
	XStoreColor

**  Constant Definitions: **

	DirectColor - used to indicate that the class of the visual is
		      Direct Color.

	DoBlue - used to specify that the blue component of a XColor
		 structure should be modified.

	DoGreen - used to specify that the green component of a XColor
		  structure should be modified.

	DoRed - used to specify that the red component of a XColor
		structure should be modified.

	PseudoColor - used to indicate that the class of the visual is
		      Pseudo Color.

	StaticColor - used to indicate that the class of the visual is
		      Static Color.

	TrueColor - used to indicate that the class of the visual is
		    True Color.

**  Macro Definitions: **

	None

**  External Variables: **

	None

**  Pseudo Code:

  Set the red, green, and blue components of the color to be stored
      equal to the values in the XColor structure passed to the module
  Set the color action flags to indicate that the red, green, and blue
      components should be stored
  Set the pixel of the color to be stored equal to the value in the XColor
      structure passed to the module
  If ( the class of the visual of the display to which the related colors
       are to be stored has some type of color ) then
    Store the color into the specified color map
    Return the pixel value of the stored color to the calling module
  End If  
  Output an error indicated that the color could not be allocated
  Return a zero to the calling module to indicate that an error has occurred

    Code:  */

unsigned long store_color (Display  *display
                          ,Visual   *visual
		          ,Colormap  colormap
		          ,XColor   *new_color)
{
   XColor color;

   color.red = new_color->red;
   color.blue = new_color->blue;
   color.green = new_color->green;
   color.flags = DoRed | DoGreen | DoBlue;
   color.pixel = new_color->pixel;
   if ( visual->class == TrueColor
     || visual->class == PseudoColor
     || visual->class == DirectColor
     || visual->class == StaticColor)
   {
      XStoreColor (display
		  ,colormap
		  ,&color);
      return color.pixel;
   }
   printf("(Error) Color not allocated.");
   return 0;
}
